@@ -43,43 +43,35 @@ package UMLS::Similarity::path;
 use strict;
 use warnings;
 use UMLS::Similarity;
+use UMLS::Similarity::ErrorHandler;
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.07';
 
 my $debug = 0;
 
 sub new
 {
     my $className = shift;
+    my $interface    = shift;
+    
     return undef if(ref $className);
-    
-    if($debug) { print STDERR "In UMLS::Similarity::path->new()\n"; }
-    
-    my $interface = shift;
-    
+  
     my $self = {};
-    
-    # Initialize the error string and the error level.
-    $self->{'errorString'} = "";
-    $self->{'error'} = 0;
-    
+        
     # Bless the object.
     bless($self, $className);
-    
+        
     # The backend interface object.
     $self->{'interface'} = $interface;
-    
-    if(!$interface)
-    {
-	$self->{'errorString'} .= "\nError (UMLS::Similarity::path->new()) - ";
-	$self->{'errorString'} .= "An interface object is required.";
-	$self->{'error'} = 2;
+
+    #  check the configuration file if defined
+    my $errorhandler = UMLS::Similarity::ErrorHandler->new("path",  $interface);
+    if(!$errorhandler) {
+	print STDERR "The UMLS::Similarity::ErrorHandler did not load properly\n";
+	exit;
     }
-    
-    # The backend interface object.
-    $self->{'interface'} = $interface;
-    
+
     return $self;
 }
 
@@ -94,7 +86,6 @@ sub getRelatedness
     #  get the interface
     my $interface = $self->{'interface'};
 
-    
     #  find the shortest paths
     my @paths = $interface->findShortestPath($concept1, $concept2);
     
@@ -117,26 +108,6 @@ sub getRelatedness
     return (1/$length);
 }
 
-# Method to return recent error/warning condition
-sub getError
-{
-    my $self = shift;
-    return (2, "") if(!defined $self || !ref $self);
-    
-    if($debug) { print STDERR "In UMLS::Similarity::path->getError()\n"; }
-    
-    my $dontClear = shift;
-    my $error = $self->{'error'};
-    my $errorString = $self->{'errorString'};
-    
-    if(!(defined $dontClear && $dontClear)) {
-	$self->{'error'} = 0;
-	$self->{'errorString'} = "";
-    }
-    $errorString =~ s/^\n//;
-    
-    return ($error, $errorString);
-}
 
 1;
 __END__
@@ -149,23 +120,27 @@ of concepts in the UMLS by simple edge counting.
 =head1 SYNOPSIS
 
   use UMLS::Interface;
+
   use UMLS::Similarity::path;
 
   my $umls = UMLS::Interface->new(); 
+
   die "Unable to create UMLS::Interface object.\n" if(!$umls);
-  ($errCode, $errString) = $umls->getError();
-  die "$errString\n" if($errCode);
 
   my $path = UMLS::Similarity::path->new($umls);
+
   die "Unable to create measure object.\n" if(!$path);
-  
+
   my $cui1 = "C0005767";
+
   my $cui2 = "C0007634";
-	
+
   @ts1 = $umls->getTermList($cui1);
+
   my $term1 = pop @ts1;
 
   @ts2 = $umls->getTermList($cui2);
+
   my $term2 = pop @ts2;
 
   my $value = $path->getRelatedness($cui1, $cui2);
@@ -216,7 +191,6 @@ The semantic relatedness modules in this distribution are built as
 classes that expose the following methods:
   new()
   getRelatedness()
-  getError()
 
 =head1 TYPICAL USAGE EXAMPLES
 
@@ -231,18 +205,14 @@ variable '$measure'. '$interface' contains an interface object that
 should have been created earlier in the program (UMLS-Interface).
 
 If the 'new' method is unable to create the object, '$measure' would 
-be undefined. This, as well as any other error/warning may be tested.
-
-   die "Unable to create object.\n" if(!defined $measure);
-   ($err, $errString) = $measure->getError();
-   die $errString."\n" if($err);
+be undefined.
 
 To find the semantic relatedness of the concept 'blood' (C0005767) and
 the concept 'cell' (C0007634) using the measure, we would write
 the following piece of code:
 
    $relatedness = $measure->getRelatedness('C0005767', 'C0007634');
-    
+
 =head1 SEE ALSO
 
 perl(1), UMLS::Interface
@@ -250,18 +220,18 @@ perl(1), UMLS::Interface
 perl(1), UMLS::Similarity(3)
 
 =head1 CONTACT US
-   
+
   If you have any trouble installing and using UMLS-Similarity, 
   please contact us via the users mailing list :
-    
+
       umls-similarity@yahoogroups.com
-     
+
   You can join this group by going to:
-    
+
       http://tech.groups.yahoo.com/group/umls-similarity/
-     
+
   You may also contact us directly if you prefer :
-    
+
       Bridget T. McInnes: bthomson at cs.umn.edu 
 
       Ted Pedersen : tpederse at d.umn.edu
